@@ -11,4 +11,5 @@ class App(AppBase):
     def default(self, msg):
         response = settings.DEFAULT_RESPONSE
         if response is not None:
-            msg.error(response, project_name=settings.PROJECT_NAME)
+            response = response % {'project_name': settings.PROJECT_NAME}
+            msg.error(response)
